import React, { useEffect } from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import { isDefault } from "./utilities/form";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import inputStyle from "design-to-code/dist/stylesheets/web-components/style/common.input.css";
import defaultFontStyle from "design-to-code/dist/stylesheets/web-components/style/common.default-font.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
import style from "./control.number-field.style.css";
// tree-shaking
cssVariables;
inputStyle;
defaultFontStyle;
style;
/**
 * Form control definition
 */
function NumberFieldControl(props) {
    let hasFocus = false;
    function handleFocus(callback) {
        return () => {
            props.reportValidity();
            hasFocus = true;
            if (callback)
                callback();
        };
    }
    function handleBlur(callback) {
        return () => {
            props.updateValidity();
            hasFocus = false;
            if (callback)
                callback();
        };
    }
    function handleChange() {
        return (e) => {
            const input = !e.target.value
                ? ""
                : e.target.value.replace(/\s/g, "");
            const value = parseInt(input, 10);
            if (!isNaN(value)) {
                props.onChange({ value });
            }
            else if (input.length === 0) {
                props.onChange({ value: undefined });
            }
        };
    }
    function getValue(value) {
        return typeof value === "number"
            ? value
            : typeof props.default !== "undefined" && !hasFocus
                ? props.default
                : "";
    }
    function handleWheel(e) {
        e.preventDefault();
    }
    useEffect(() => {
        if (props.elementRef.current) {
            props.elementRef.current.addEventListener("wheel", handleWheel, { passive: false });
        }
        return function cancel() {
            if (props.elementRef.current) {
                props.elementRef.current.removeEventListener("wheel", handleWheel);
            }
        };
    });
    return (React.createElement("input", { className: classNames(`dtc-number-field-control ${dtcClassName.commonInput}`, ["dtc-number-field-control__disabled", props.disabled], [
            `dtc-number-field-control__default ${dtcClassName.commonDefaultFont}`,
            isDefault(props.value, props.default),
        ]), id: props.dataLocation, type: "number", value: getValue(props.value), name: props.dataLocation, onChange: handleChange(), min: props.min, max: props.max, step: props.step, disabled: props.disabled, ref: props.elementRef, onBlur: handleBlur(props.updateValidity), onFocus: handleFocus(props.reportValidity) }));
}
export { NumberFieldControl };
export default NumberFieldControl;
