import React, { useState } from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import cssVariables from "design-to-code/dist/stylesheets/web-components/style/global.css-variables.css";
import invalidMessageStyle from "design-to-code/dist/stylesheets/web-components/style/common.invalid-message.css";
import ellipsisStyle from "design-to-code/dist/stylesheets/web-components/style/common.ellipsis.css";
import chevronStyle from "design-to-code/dist/stylesheets/web-components/style/common.chevron.css";
import chevronUpStyle from "design-to-code/dist/stylesheets/web-components/style/common.chevron-up.css";
import style from "./section.validation.style.css";
import dtcClassName from "design-to-code/dist/esm/web-components/style/class-names";
// tree-shaking
cssVariables;
invalidMessageStyle;
ellipsisStyle;
chevronStyle;
chevronUpStyle;
style;
/**
 * Schema form component definition
 */
function SectionValidation(props) {
    const validationIdentifier = "validation";
    const [expanded, setExpanded] = useState(false);
    function renderInvalidMessage() {
        return (React.createElement("div", { className: `dtc-section-validation_message ${dtcClassName.commonEllipsis}`, title: props.invalidMessage }, props.invalidMessage));
    }
    function renderExpandTrigger() {
        if (props.validationErrors.length > 1) {
            return (React.createElement("button", { className: classNames(`dtc-section-validation_expand-trigger ${dtcClassName.commonChevron}`, [
                    `dtc-section-validation_expand-trigger__active ${dtcClassName.commonChevron} ${dtcClassName.commonChevronUp}`,
                    expanded,
                ]), onClick: handleExpandTrigger, "aria-expanded": expanded, "aria-controls": getId(), title: "Expand to see full error list" }));
        }
    }
    function renderValidationErrorContainer() {
        return (React.createElement("ul", { id: getId(), className: "dtc-section-validation_error-list" }, renderAllValidationErrors()));
    }
    function renderAllValidationErrors() {
        if (expanded) {
            return props.validationErrors.map((validationError, index) => {
                return (React.createElement("li", { key: `${props.dataLocation}${index}`, className: `dtc-section-validation_error-list-item ${dtcClassName.commonEllipsis}` },
                    React.createElement("span", { title: validationError.invalidMessage }, validationError.invalidMessage),
                    React.createElement("div", { className: `dtc-section-validation_error-list-item-details ${dtcClassName.commonEllipsis}`, title: `data location: ${validationError.dataLocation}` }, validationError.dataLocation)));
            });
        }
    }
    function handleExpandTrigger(e) {
        e.preventDefault();
        setExpanded(!expanded);
    }
    function getId() {
        return `${props.dataLocation}${validationIdentifier}`;
    }
    return (React.createElement("div", { className: "dtc-section-validation" },
        renderExpandTrigger(),
        React.createElement("div", { className: `dtc-section-validation_control-region ${dtcClassName.commonInvalidMessage}` },
            renderInvalidMessage(),
            renderValidationErrorContainer())));
}
export { SectionValidation };
export default SectionValidation;
