import React from "react";
import { classNames } from "@microsoft/fast-web-utilities";
import { mapCSSInlineStyleToCSSPropertyDictionary, } from "design-to-code/dist/esm/data-utilities/mapping.mdn-data";
import { CSSRef } from "./control.css-ref";
import { memoize } from "lodash-es";
import cssStyle from "./control.align.style.css";
// tree-shaking
cssStyle;
/**
 * This is currently experimental
 */
/**
 * Custom form control definition for CSS
 */
function CSSControl(props) {
    const memoizeMappedStyleToCSSPropertyDictionary = memoize(mapCSSInlineStyleToCSSPropertyDictionary);
    function renderCSSProperties() {
        const css = Object.assign({}, props.css);
        const renderedCssControls = [];
        if (props.cssControls) {
            props.cssControls.forEach((cssControl) => {
                cssControl.updateProps({
                    css: Object.assign({}, memoizeMappedStyleToCSSPropertyDictionary(props.value || "")),
                    value: props.value,
                    onChange: handleMultiplePropertyOnChange,
                });
                renderedCssControls.push(cssControl.render());
                cssControl.getPropertyNames().forEach((propertyName) => {
                    delete css[propertyName];
                });
            });
        }
        return [
            ...renderedCssControls,
            ...Object.entries(css).map(([cssPropertyName, cssProperty]) => {
                return renderCSSProperty(cssProperty, cssPropertyName, memoizeMappedStyleToCSSPropertyDictionary(props.value)[cssPropertyName] || "");
            }),
        ];
    }
    function renderCSSProperty(cssProperty, cssPropertyName, cssPropertyValue) {
        if (!cssProperty || !cssProperty.name || !cssProperty.syntax) {
            return null;
        }
        return (React.createElement("fieldset", { key: cssPropertyName },
            React.createElement("legend", null, cssProperty.name),
            React.createElement(CSSRef, { syntax: cssProperty.syntax, onChange: handleOnChange(cssPropertyName), mapsToProperty: cssPropertyName, value: cssPropertyValue, dictionaryId: props.dictionaryId, dataLocation: props.dataLocation, stylesheets: props.stylesheets })));
    }
    function handleMultiplePropertyOnChange(css) {
        resolveCSS(css);
    }
    function handleOnChange(propertyName) {
        return (value) => {
            resolveCSS({
                [propertyName]: value,
            });
        };
    }
    function resolveCSS(css) {
        const cssDictionary = Object.assign(Object.assign({}, memoizeMappedStyleToCSSPropertyDictionary(props.value)), css);
        props.onChange({
            value: `${Object.keys(cssDictionary)
                .reduce((previousValue, propertyName) => {
                if (!cssDictionary[propertyName]) {
                    return previousValue;
                }
                return `${previousValue} ${propertyName}: ${cssDictionary[propertyName]};`;
            }, "")
                .trim()}` || undefined,
        });
    }
    return React.createElement("div", { className: classNames("dtc-css") }, renderCSSProperties());
}
export { CSSControl };
export default CSSControl;
