import React from "react";
import { DragDropItemType } from "./navigation-tree-item.props";
import { useDrag, useDrop, } from "react-dnd";
import { getHoverLocation, refNode } from "./navigation-tree-item.utilities";
function editableOverlay(className, value, handleInputChange, handleInputBlur, handleInputKeyDown, inputRef) {
    return (React.createElement("input", { className: className, ref: inputRef, key: "overlay", value: value, onChange: handleInputChange, onBlur: handleInputBlur, onKeyDown: handleInputKeyDown }));
}
function treeItem(handleClick, handleInputChange, handleInputBlur, handleInputKeyDown, handleExpandClick, handleKeyDown, isEditing, isCollapsible, className, expandTriggerClassName, contentClassName, displayTextInputClassName, text, dictionaryId, navigationConfigId, inputRef, itemRef, ref) {
    const displayText = isEditing
        ? editableOverlay(displayTextInputClassName, text, handleInputChange, handleInputBlur, handleInputKeyDown, inputRef)
        : isCollapsible
            ? treeItemCollapsible(handleClick, handleKeyDown, contentClassName, text, dictionaryId, navigationConfigId, ref)
            : treeItemEndLeaf(handleClick, handleKeyDown, contentClassName, text, dictionaryId, navigationConfigId, ref);
    return (React.createElement("span", { ref: itemRef, className: className },
        React.createElement("span", { className: expandTriggerClassName, onClick: handleExpandClick }),
        displayText));
}
function treeItemEndLeaf(handleClick, handleKeyDown, contentClassName, text, dictionaryId, navigationConfigId, ref) {
    return (React.createElement("a", { className: contentClassName, onClick: handleClick, ref: ref, tabIndex: 0, onKeyDown: handleKeyDown, "data-dictionaryid": dictionaryId, "data-navigationconfigid": navigationConfigId }, text));
}
function treeItemCollapsible(handleClick, handleKeyDown, contentClassName, text, dictionaryId, navigationConfigId, ref) {
    return (React.createElement("span", { className: contentClassName, onClick: handleClick, ref: ref, tabIndex: 0, onKeyDown: handleKeyDown, "data-dictionaryid": dictionaryId, "data-navigationconfigid": navigationConfigId }, text));
}
export const NavigationTreeItem = ({ text, className, expandTriggerClassName, contentClassName, displayTextInputClassName, isEditing, isCollapsible, handleClick, handleInputChange, handleInputBlur, handleInputKeyDown, handleExpandClick, handleKeyDown, dictionaryId, navigationConfigId, inputRef, itemRef, }) => {
    return treeItem(handleClick, handleInputChange, handleInputBlur, handleInputKeyDown, handleExpandClick, handleKeyDown, isEditing, isCollapsible, className, expandTriggerClassName, contentClassName, displayTextInputClassName, text, dictionaryId, navigationConfigId, inputRef, itemRef);
};
export const DraggableNavigationTreeItem = ({ type, text, handleClick, handleInputChange, handleInputBlur, handleInputKeyDown, handleExpandClick, handleKeyDown, className, expandTriggerClassName, contentClassName, displayTextInputClassName, isCollapsible, isEditing, inputRef, itemRef, dragStart, dragEnd, dragHover, dictionaryId, navigationConfigId, index, }) => {
    let ref = null;
    let cachedRef = null;
    let cachedRefBoundingClientRect;
    const drag = useDrag({
        type,
        item: dragStart(dictionaryId, type),
        end() {
            // TODO: investigate why when not dropped on a drop target this takes extra time to respond
            // see issue: https://github.com/microsoft/fast/issues/2867
            dragEnd();
        },
    });
    const dragSource = drag[1];
    const drop = useDrop({
        accept: [DragDropItemType.linkedData, DragDropItemType.linkedDataUndroppable],
        hover(item, monitor) {
            /**
             * When the hovered element changes, reset the cached ref and
             * the cached bounding client rect to reduce performance cost
             */
            if (cachedRef !== ref) {
                cachedRef = ref;
                cachedRefBoundingClientRect = ref.getBoundingClientRect();
            }
            dragHover(type, dictionaryId, navigationConfigId, index, getHoverLocation(type, monitor, cachedRefBoundingClientRect));
        },
    });
    const dropTarget = drop[1];
    return treeItem(handleClick, handleInputChange, handleInputBlur, handleInputKeyDown, handleExpandClick, handleKeyDown, isEditing, isCollapsible, className, expandTriggerClassName, contentClassName, displayTextInputClassName, text, dictionaryId, navigationConfigId, inputRef, itemRef, (node) => {
        ref = node;
        return refNode(node, type, dragSource, dropTarget);
    });
};
