import { getLinkedData, MessageSystemDataTypeAction, MessageSystemType, } from "design-to-code";
import { HoverLocation, } from "./navigation.props";
import { DragDropItemType } from "./navigation-tree-item.props";
export function isActiveItem(activeDictionaryId, dictionaryId, activeNavigationConfigId, navigationConfigId) {
    return (activeDictionaryId === dictionaryId &&
        activeNavigationConfigId === navigationConfigId);
}
export function getDraggableItemClassName(isCollapsible, isDraggable, isDroppable, dictionaryId, navigationConfigId, hoveredItem, activeDictionaryId, activeNavigationConfigId, defaultLinkedDataDroppableDataLocation, navigationItem, navigationItemExpandable, navigationItemActive, navigationItemDraggable, navigationItemDroppable, navigationItemHover, navigationItemHoverAfter, navigationItemHoverBefore) {
    let className = navigationItem;
    if (isCollapsible) {
        className += ` ${navigationItemExpandable}`;
    }
    if (isActiveItem(activeDictionaryId, dictionaryId, activeNavigationConfigId, navigationConfigId)) {
        className += ` ${navigationItemActive}`;
    }
    if (isDraggable) {
        className += ` ${navigationItemDraggable}`;
    }
    if (isDroppable) {
        className += ` ${navigationItemDroppable}`;
    }
    if (hoveredItem !== null &&
        hoveredItem[1] === dictionaryId &&
        hoveredItem[2] === navigationConfigId) {
        if (hoveredItem[0] === DragDropItemType.linkedDataContainer ||
            ((hoveredItem[0] === DragDropItemType.linkedData ||
                hoveredItem[0] === DragDropItemType.rootLinkedData) &&
                defaultLinkedDataDroppableDataLocation &&
                hoveredItem[3] === HoverLocation.center)) {
            className += ` ${navigationItemHover}`;
        }
        else if (hoveredItem[0] === DragDropItemType.linkedData ||
            hoveredItem[0] === DragDropItemType.linkedDataUndroppable) {
            if (hoveredItem[3] === HoverLocation.after) {
                className += ` ${navigationItemHoverAfter}`;
            }
            else {
                className += ` ${navigationItemHoverBefore}`;
            }
        }
    }
    return className;
}
export function getDragStartState(dictionaryId, index, dataDictionary, navigationDictionary) {
    return {
        linkedData: getLinkedData(dataDictionary, [dictionaryId]),
        linkedDataLocation: [
            navigationDictionary[0][dictionaryId][0][navigationDictionary[0][dictionaryId][1]].parentDictionaryItem.id,
            navigationDictionary[0][dictionaryId][0][navigationDictionary[0][dictionaryId][1]].parentDictionaryItem.dataLocation,
            index,
        ],
    };
}
export function getDragStartMessage(dictionaryId, navigationId, navigationDictionary) {
    return {
        type: MessageSystemType.data,
        action: MessageSystemDataTypeAction.removeLinkedData,
        dictionaryId: navigationDictionary[0][dictionaryId][0][navigationDictionary[0][dictionaryId][1]].parentDictionaryItem.id,
        dataLocation: navigationDictionary[0][dictionaryId][0][navigationDictionary[0][dictionaryId][1]].parentDictionaryItem.dataLocation,
        linkedData: navigationDictionary[0][navigationDictionary[0][dictionaryId][0][navigationDictionary[0][dictionaryId][1]].parentDictionaryItem.id][0][navigationDictionary[0][dictionaryId][0][navigationDictionary[0][dictionaryId][1]].parentDictionaryItem.dataLocation].data.filter((value) => {
            return value.id === dictionaryId;
        }),
        options: {
            originatorId: navigationId,
        },
    };
}
export function getDragEndMessage(navigationId, hoveredItem, linkedData, linkedDataLocation, defaultLinkedDataDroppableDataLocation) {
    if (hoveredItem === null) {
        return {
            type: MessageSystemType.data,
            action: MessageSystemDataTypeAction.addLinkedData,
            linkedData,
            dictionaryId: linkedDataLocation[0],
            dataLocation: linkedDataLocation[1],
            index: linkedDataLocation[2],
            options: {
                originatorId: navigationId,
            },
        };
    }
    const dropOntoLinkedData = (linkedDataLocation[1] === "" ||
        linkedDataLocation[1] === defaultLinkedDataDroppableDataLocation) &&
        defaultLinkedDataDroppableDataLocation &&
        hoveredItem[3] === HoverLocation.center;
    return {
        type: MessageSystemType.data,
        action: MessageSystemDataTypeAction.addLinkedData,
        linkedData: linkedData,
        dictionaryId: linkedDataLocation[0],
        dataLocation: dropOntoLinkedData
            ? defaultLinkedDataDroppableDataLocation
            : linkedDataLocation[1],
        index: dropOntoLinkedData ? void 0 : linkedDataLocation[2],
        options: {
            originatorId: navigationId,
        },
    };
}
export function getDragHoverState(dictionaryId, navigationConfigId, type, location, index, hoveredItem, navigationDictionary, defaultLinkedDataDroppableDataLocation) {
    let parentDictionaryId = dictionaryId;
    let parentDataLocation = navigationDictionary[0][dictionaryId][0][navigationConfigId].relativeDataLocation;
    const isLinkedDataContainer = type === DragDropItemType.linkedDataContainer;
    const isDroppableLinkedData = type === DragDropItemType.linkedData || type === DragDropItemType.rootLinkedData;
    if (isDroppableLinkedData &&
        defaultLinkedDataDroppableDataLocation &&
        location === HoverLocation.center) {
        parentDataLocation = defaultLinkedDataDroppableDataLocation;
    }
    else if (!isLinkedDataContainer &&
        navigationDictionary[0][dictionaryId][0][navigationConfigId]
            .parentDictionaryItem !== undefined) {
        parentDataLocation =
            navigationDictionary[0][dictionaryId][0][navigationConfigId]
                .parentDictionaryItem.dataLocation;
        parentDictionaryId =
            navigationDictionary[0][dictionaryId][0][navigationConfigId]
                .parentDictionaryItem.id;
    }
    if (hoveredItem === null ||
        dictionaryId !== hoveredItem[1] ||
        navigationConfigId !== hoveredItem[2] ||
        location !== hoveredItem[3]) {
        return {
            hoveredItem: [type, dictionaryId, navigationConfigId, location],
            linkedDataLocation: [
                parentDictionaryId,
                parentDataLocation,
                isLinkedDataContainer
                    ? undefined
                    : location === HoverLocation.before
                        ? index
                        : index + 1,
            ],
        };
    }
    return;
}
